summaryrefslogtreecommitdiff
path: root/www/wiki/load.php
diff options
context:
space:
mode:
authorYaco <franco@reevo.org>2019-07-31 14:50:50 -0300
committerYaco <franco@reevo.org>2019-07-31 14:50:50 -0300
commit3848848fc3bc2db035c824f1453635949505d76e (patch)
tree71fd898ebb220e7ba034cf2bc1bf708fdd0d6219 /www/wiki/load.php
parent2dfe0b926fe5c6c4f27ad1f9bc1c1377cb091111 (diff)
ACTUALIZA MW a 1.31.3, SMW a 3.0.2 y extensiones menores
Diffstat (limited to 'www/wiki/load.php')
-rw-r--r--www/wiki/load.php8
1 files changed, 3 insertions, 5 deletions
diff --git a/www/wiki/load.php b/www/wiki/load.php
index 974771f9..1997fe73 100644
--- a/www/wiki/load.php
+++ b/www/wiki/load.php
@@ -36,11 +36,9 @@ if ( !$wgRequest->checkUrlExtension() ) {
return;
}
-// Don't initialise ChronologyProtector from object cache, and
-// don't wait for unrelated MediaWiki writes when querying ResourceLoader.
-MediaWikiServices::getInstance()->getDBLoadBalancerFactory()->setRequestInfo( [
- 'ChronologyProtection' => 'false',
-] );
+// Disable ChronologyProtector so that we don't wait for unrelated MediaWiki
+// writes when getting database connections for ResourceLoader. (T192611)
+MediaWikiServices::getInstance()->getDBLoadBalancerFactory()->disableChronologyProtection();
// Set up ResourceLoader
$resourceLoader = new ResourceLoader(